@@ -2,8 +2,8 @@ from .RANDFUNC import *
 
 __title__ = "randfunc"
 __summary__ = "Randfunc is a collection of random functions."
-__uri__ = "https://github.com/CodeWithSwastik/randfunc"
-__version__ = "0.0.2"
+__uri__ = "https://github.com/Cu3t0m/randfunc"
+__version__ = "0.0.3"
 __author__ = "Custom"
 __email__ = "diwanmohamedfaheer@gmail.com"
 __license__ = "MIT License"
